@@ -32,6 +32,7 @@ __all__ = (
     "DatasetImportJobSummaryTypeDef",
     "DatasetSummaryTypeDef",
     "EncryptionConfigTypeDef",
+    "ErrorMetricTypeDef",
     "EvaluationParametersTypeDef",
     "EvaluationResultTypeDef",
     "FeaturizationConfigTypeDef",
@@ -152,6 +153,10 @@ DatasetSummaryTypeDef = TypedDict(
 
 EncryptionConfigTypeDef = TypedDict("EncryptionConfigTypeDef", {"RoleArn": str, "KMSKeyArn": str})
 
+ErrorMetricTypeDef = TypedDict(
+    "ErrorMetricTypeDef", {"ForecastType": str, "WAPE": float, "RMSE": float}, total=False
+)
+
 EvaluationParametersTypeDef = TypedDict(
     "EvaluationParametersTypeDef",
     {"NumberOfBacktestWindows": int, "BackTestWindowOffset": int},
@@ -275,7 +280,11 @@ class IntegerParameterRangeTypeDef(
 
 MetricsTypeDef = TypedDict(
     "MetricsTypeDef",
-    {"RMSE": float, "WeightedQuantileLosses": List["WeightedQuantileLossTypeDef"]},
+    {
+        "RMSE": float,
+        "WeightedQuantileLosses": List["WeightedQuantileLossTypeDef"],
+        "ErrorMetrics": List["ErrorMetricTypeDef"],
+    },
     total=False,
 )
 
@@ -501,6 +510,7 @@ DescribePredictorResponseTypeDef = TypedDict(
         "PredictorName": str,
         "AlgorithmArn": str,
         "ForecastHorizon": int,
+        "ForecastTypes": List[str],
         "PerformAutoML": bool,
         "PerformHPO": bool,
         "TrainingParameters": Dict[str, str],
